@@ -8,10 +8,10 @@
     #include <R.h>
 
     // for windows and Mac build need to undo declarations in R.h (R>1.8.0)
-    #ifdef IEEE_754
-    #undef ISNAN
-    #define ISNAN(x)   R_IsNaNorNA(x)
-    #endif
+    //#ifdef IEEE_754
+    //#undef ISNAN
+    //#define ISNAN(x)   R_IsNaNorNA(x)
+    //#endif
 
     #define GBM_FAILED(hr) ((unsigned long)hr != 0)
     typedef unsigned long GBMRESULT;
