@@ -28,8 +28,8 @@ public:
     CNodeCategorical();
     ~CNodeCategorical();
 
-    HRESULT PrintSubtree(unsigned long cIndent);
-    HRESULT TransferTreeToRList(int &iNodeID,
+    GBMRESULT PrintSubtree(unsigned long cIndent);
+    GBMRESULT TransferTreeToRList(int &iNodeID,
                                 CDataset *pData,
                                 int *aiSplitVar,
                                 double *adSplitPoint,
@@ -49,7 +49,7 @@ public:
                           unsigned long cCol,
                           unsigned long iRow);
 
-    HRESULT RecycleSelf(CNodeFactory *pNodeFactory);
+    GBMRESULT RecycleSelf(CNodeFactory *pNodeFactory);
 
     unsigned long *aiLeftCategory;
     unsigned long cLeftCategory;
