@@ -27,7 +27,7 @@ public:
 
     virtual ~CPoisson();
 
-    HRESULT ComputeWorkingResponse(double *adY,
+    GBMRESULT ComputeWorkingResponse(double *adY,
                                    double *adMisc,
                                    double *adOffset,
                                    double *adWeight,
@@ -43,14 +43,14 @@ public:
                          double *adF,
                          unsigned long cLength);
 
-    HRESULT InitF(double *adY, 
+    GBMRESULT InitF(double *adY, 
                   double *adMisc,
                   double *adOffset,
                   double *adWeight,
                   double &dInitF, 
                   unsigned long cLength);
 
-    HRESULT FitBestConstant(double *adY,
+    GBMRESULT FitBestConstant(double *adY,
                             double *adMisc,
                             double *adOffset,
                             double *adW,
